@@ -9,9 +9,9 @@
 #include <QtCore/QDateTime>
 #include <Soprano/Vocabulary/RDF>
 
-#include <dms-copy/simpleresource.h>
+#include <nepomuk2/simpleresource.h>
 
-namespace Nepomuk {
+namespace Nepomuk2 {
 namespace NAO {
 /**
  * Represents a single or a group of individuals 
@@ -19,7 +19,7 @@ namespace NAO {
 class Party
 {
 public:
-    Party(Nepomuk::SimpleResource* res)
+    Party(Nepomuk2::SimpleResource* res)
       : m_res(res)
     {}
 
@@ -870,7 +870,7 @@ protected:
     virtual QUrl resourceType() const { return QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/08/15/nao#Party", QUrl::StrictMode); }
 
 private:
-    Nepomuk::SimpleResource* m_res;
+    Nepomuk2::SimpleResource* m_res;
 };
 }
 }
