@@ -85,6 +85,16 @@ bool SerializerPluginKAlarm::deserialize(Item& item, const QByteArray& label, QI
         else
         {
             EventAttribute* evAttr = dynamic_cast<EventAttribute*>(a);
+            if (!evAttr)
+            {
+                kError(5954) << "deserialize(): unknown type EventAttribute: retrying";
+                AttributeFactory::registerAttribute<KAlarmCal::EventAttribute>();
+                mRegistered = QLatin1String("x");   // set to any non-null string
+                if (item.hasAttribute<EventAttribute>())
+                    evAttr = item.attribute<EventAttribute>();
+                if (evAttr)
+                    kError(5954) << "deserialize(): EventAttribute was not already registered";
+            }
             if (!evAttr)
                 kFatal(5954) << "deserialize(): Event with uid" << event.id() << "contains unknown type EventAttribute";
             else
