@@ -24,15 +24,18 @@
 
 #include <KDE/KDialog>
 
+namespace Akonadi_Contacts_Resource {
+class ContactsResourceSettings;
+}
 class KConfigDialogManager;
 
-namespace AkonadiFuture {
+namespace Akonadi {
 
 class SettingsDialog : public KDialog
 {
   Q_OBJECT
   public:
-    explicit SettingsDialog( WId windowId );
+    explicit SettingsDialog( Akonadi_Contacts_Resource::ContactsResourceSettings* settings, WId windowId );
 
   private Q_SLOTS:
     void save();
@@ -41,6 +44,7 @@ class SettingsDialog : public KDialog
   private:
     Ui::SettingsDialog ui;
     KConfigDialogManager* mManager;
+    Akonadi_Contacts_Resource::ContactsResourceSettings *mSettings;
 };
 
 }
