@@ -18,6 +18,8 @@
 
 #include "carddavprotocol.h"
 
+#include <kabc/addressee.h>
+
 #include <QtCore/QStringList>
 #include <QtXml/QDomDocument>
 
@@ -25,17 +27,18 @@ CarddavProtocol::CarddavProtocol()
 {
   QDomDocument document;
 
-  QDomElement queryElement = document.createElementNS( "urn:ietf:params:xml:ns:carddav", "addressbook-query" );
-  document.appendChild( queryElement );
+  QDomElement propfindElement = document.createElementNS( "DAV:", "propfind" );
+  document.appendChild( propfindElement );
 
   QDomElement propElement = document.createElementNS( "DAV:", "prop" );
-  queryElement.appendChild( propElement );
+  propfindElement.appendChild( propElement );
 
   propElement.appendChild( document.createElementNS( "DAV:", "displayname" ) );
   propElement.appendChild( document.createElementNS( "DAV:", "resourcetype" ) );
   propElement.appendChild( document.createElementNS( "DAV:", "getetag" ) );
 
   mItemsQueries << document;
+  mItemsMimeTypes << KABC::Addressee::mimeType();
 }
 
 bool CarddavProtocol::supportsPrincipals() const
@@ -45,7 +48,7 @@ bool CarddavProtocol::supportsPrincipals() const
 
 bool CarddavProtocol::useReport() const
 {
-  return true;
+  return false;
 }
 
 bool CarddavProtocol::useMultiget() const
@@ -91,6 +94,11 @@ QList<QDomDocument> CarddavProtocol::itemsQueries() const
   return mItemsQueries;
 }
 
+QString CarddavProtocol::mimeTypeForQuery( int index ) const
+{
+  return mItemsMimeTypes.at( index );
+}
+
 QDomDocument CarddavProtocol::itemsReportQuery( const QStringList &urls ) const
 {
   QDomDocument document;
