@@ -43,6 +43,8 @@
 #include <akonadi/collectionfetchscope.h>
 #include <akonadi/changerecorder.h>
 #include <akonadi/itemfetchscope.h>
+#include <akonadi/specialcollections.h>
+#include <akonadi/session.h>
 
 #include "collectionannotationsattribute.h"
 #include "collectionflagsattribute.h"
@@ -63,13 +65,14 @@
 #include "addcollectiontask.h"
 #include "additemtask.h"
 #include "changecollectiontask.h"
+#include "changeitemsflagstask.h"
 #include "changeitemtask.h"
 #include "expungecollectiontask.h"
 #include "movecollectiontask.h"
-#include "moveitemtask.h"
+#include "moveitemstask.h"
 #include "removecollectionrecursivetask.h"
 #include "removecollectiontask.h"
-#include "removeitemtask.h"
+#include "removeitemstask.h"
 #include "retrievecollectionmetadatatask.h"
 #include "retrievecollectionstask.h"
 #include "retrieveitemtask.h"
@@ -152,6 +155,18 @@ ImapResource::ImapResource( const QString &id )
   new ResourceAdaptor( this );
   setNeedsNetwork( needsNetwork() );
 
+  // Migration issue: trash folder had ID in config, but didn't have SpecialCollections attribute, fix that.
+  if (!Settings::self()->trashCollectionMigrated()) {
+    const Akonadi::Collection::Id trashCollection = Settings::self()->trashCollection();
+    if (trashCollection != -1) {
+      Collection attributeCollection(trashCollection);
+      SpecialCollections::setSpecialCollectionType("trash", attributeCollection);
+    }
+    Settings::self()->setTrashCollectionMigrated(true);
+  }
+
+  m_bodyCheckSession = new Akonadi::Session( identifier().toLatin1() + "_body_checker");
+
   m_statusMessageTimer = new QTimer( this );
   m_statusMessageTimer->setSingleShot( true );
   connect( m_statusMessageTimer, SIGNAL(timeout()), SLOT(clearStatusMessage()) );
@@ -160,6 +175,7 @@ ImapResource::ImapResource( const QString &id )
 
 ImapResource::~ImapResource()
 {
+  delete m_bodyCheckSession;
 }
 
 void ImapResource::setFastSyncEnabled( bool fastSync )
@@ -339,33 +355,44 @@ void ImapResource::itemChanged( const Item &item, const QSet<QByteArray> &parts
   queueTask( task );
 }
 
-void ImapResource::itemRemoved( const Akonadi::Item &item )
+void ImapResource::itemsFlagsChanged( const Item::List& items, const QSet< QByteArray >& addedFlags,
+                                      const QSet< QByteArray >& removedFlags )
 {
-  ResourceStateInterface::Ptr state = ::ResourceState::createRemoveItemState( this, item );
+  emit status( AgentBase::Running, i18nc( "@info:status", "Updating items" ) );
 
-  const QString mailBox = state->mailBoxForCollection( item.parentCollection(), false );
+  ResourceStateInterface::Ptr state = ::ResourceState::createChangeItemsFlagsState( this, items, addedFlags, removedFlags );
+  ChangeItemsFlagsTask *task = new ChangeItemsFlagsTask( state, this );
+  task->start( m_pool );
+  queueTask( task );
+}
+
+void ImapResource::itemsRemoved( const Akonadi::Item::List &items )
+{
+  ResourceStateInterface::Ptr state = ::ResourceState::createRemoveItemsState( this, items );
+
+  const QString mailBox = state->mailBoxForCollection( items.first().parentCollection(), false );
   if ( mailBox.isEmpty() ) {
     // this item will be removed soon by its parent collection
     changeProcessed();
     return;
   }
 
-  emit status( AgentBase::Running, i18nc( "@info:status", "Removing item from '%1'", item.parentCollection().name() ) );
+  emit status( AgentBase::Running, i18nc( "@info:status", "Removing items" ) );
 
-  RemoveItemTask *task = new RemoveItemTask( state, this );
+  RemoveItemsTask *task = new RemoveItemsTask( state, this );
   task->start( m_pool );
   queueTask( task );
 }
 
-void ImapResource::itemMoved( const Akonadi::Item &item, const Akonadi::Collection &source,
-                              const Akonadi::Collection &destination )
+void ImapResource::itemsMoved( const Akonadi::Item::List &items, const Akonadi::Collection &source,
+                               const Akonadi::Collection &destination )
 {
-  Q_ASSERT( item.parentCollection() == destination ); // should have been set by the server
+  Q_ASSERT( items.first().parentCollection() == destination ); // should have been set by the server
 
-  emit status( AgentBase::Running, i18nc( "@info:status", "Moving item from '%1' to '%2'", source.name(), destination.name() ) );
+  emit status( AgentBase::Running, i18nc( "@info:status", "Moving items from '%1' to '%2'", source.name(), destination.name() ) );
 
-  ResourceStateInterface::Ptr state = ::ResourceState::createMoveItemState( this, item, source, destination );
-  MoveItemTask *task = new MoveItemTask( state, this );
+  ResourceStateInterface::Ptr state = ::ResourceState::createMoveItemsState( this, items, source, destination );
+  MoveItemsTask *task = new MoveItemsTask( state, this );
   task->start( m_pool );
   queueTask( task );
 }
@@ -419,7 +446,8 @@ void ImapResource::retrieveItems( const Collection &col )
   setItemStreamingEnabled( true );
 
   ResourceStateInterface::Ptr state = ::ResourceState::createRetrieveItemsState( this, col );
-  RetrieveItemsTask *task = new RetrieveItemsTask( state, this );
+  RetrieveItemsTask *task = new RetrieveItemsTask( state, m_bodyCheckSession, this );
+  connect(task, SIGNAL(status(int,QString)), SIGNAL(status(int,QString)));
   task->setFastSyncEnabled( m_fastSync );
   task->start( m_pool );
   queueTask( task );
@@ -524,7 +552,7 @@ void ImapResource::reconnect()
 
   setOnline( !needsNetwork()
 #ifndef IMAPRESOURCE_NO_SOLID
-			 ||
+                         ||
              Solid::Networking::status() == Solid::Networking::Unknown ||
              Solid::Networking::status() == Solid::Networking::Connected
 #endif
