@@ -43,7 +43,7 @@ class SessionPool;
 class ResourceState;
 class SubscriptionDialog;
 
-class ImapResource : public Akonadi::ResourceBase, public Akonadi::AgentBase::ObserverV2
+class ImapResource : public Akonadi::ResourceBase, public Akonadi::AgentBase::ObserverV3
 {
   Q_OBJECT
   Q_CLASSINFO( "D-Bus Interface", "org.kde.Akonadi.Imap.Resource" )
@@ -51,7 +51,7 @@ class ImapResource : public Akonadi::ResourceBase, public Akonadi::AgentBase::Ob
   using Akonadi::AgentBase::Observer::collectionChanged;
 
 public:
-  ImapResource( const QString &id );
+  explicit ImapResource( const QString &id );
   ~ImapResource();
 
 
@@ -85,9 +85,10 @@ protected Q_SLOTS:
 protected:
   virtual void itemAdded( const Akonadi::Item &item, const Akonadi::Collection &collection );
   virtual void itemChanged( const Akonadi::Item &item, const QSet<QByteArray> &parts );
-  virtual void itemRemoved( const Akonadi::Item &item );
-  virtual void itemMoved( const Akonadi::Item &item, const Akonadi::Collection &source,
-                          const Akonadi::Collection &destination );
+  virtual void itemsFlagsChanged( const Akonadi::Item::List &items, const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags );
+  virtual void itemsRemoved( const Akonadi::Item::List &items );
+  virtual void itemsMoved( const Akonadi::Item::List &item, const Akonadi::Collection &source,
+                           const Akonadi::Collection &destination );
 
 
   virtual void collectionAdded( const Akonadi::Collection &collection, const Akonadi::Collection &parent );
@@ -136,6 +137,7 @@ private:
   QPointer<SubscriptionDialog> mSubscriptions;
   ImapIdleManager *m_idle;
   bool m_fastSync;
+  Akonadi::Session *m_bodyCheckSession;
   QTimer *m_statusMessageTimer;
 };
 
